@@ -1,8 +1,9 @@
 import time
-import win32api, win32con, win32gui, win32clipboard, win32print
+import win32api, win32con, win32gui, win32clipboard, win32print, win32com.client
 from typing import *
 import os
 import json
+import winsound
 
 
 class KeyCode:
@@ -165,6 +166,21 @@ class Mouse:
         win32api.SetCursorPos((self.x, self.y))
         return self
 
+    @staticmethod
+    def mouse_position(trans_dpi: bool = False) -> Tuple[int]:
+        """
+        返回当前鼠标所在坐标点
+        :param trans_dpi: 是否转换为分辨率下的坐标点
+        :return: 元组形式返回坐标点x,y
+        """
+        if trans_dpi is False:
+            scale = 1
+        else:
+            scale = Window.ComputerDeviceScale()
+        pos = win32gui.GetCursorPos()
+        trans_pos = tuple(map(lambda x: round(x*scale), pos))
+        return trans_pos
+
     def roll(self, down=True, time_count: int = 1):
         """
         鼠标中键滚动
@@ -562,6 +578,16 @@ class Window:
             search_res = json.dumps(search_res, indent=2, ensure_ascii=True, sort_keys=True)
         return search_res
 
+class Voice:
+    @staticmethod
+    def Speak(message: str):
+        """
+        调用系统声音对文字进行朗读
+        :param message: 需要进行朗读的文字
+        :return:
+        """
+        spk = win32com.client.Dispatch("SAPI.SpVoice")
+        spk.Speak(message)
 
 class Custom:
     """
@@ -577,15 +603,3 @@ class Custom:
         Message.SetText(input_, file)                                    # 进行文件输入
         win32api.SendMessage(window, win32con.WM_COMMAND, 1, button)     # 点击打开按钮进行上传
 
-
-
-
-
-
-
-
-
-
-
-
-
